node_label: Create node labels for pedigree and descendancy charts

View source: R/tree.R

node_labelR Documentation

Create node labels for pedigree and descendancy charts

Description

This function creates brief summaries of individuals and relationships formatted for the DiagrammeR::mermaid() function.

Usage

node_label(gedcom, xref)

Arguments

gedcom

A tidyged object.

xref

The xref of the Individual or Family Group record.

Value

A string describing a node to use in the DiagrammeR::mermaid() function.


jl5000/visged documentation built on June 15, 2022, 8:38 p.m.