node_style: Create node styles for pedigree and descendancy charts

View source: R/tree.R

node_styleR Documentation

Create node styles for pedigree and descendancy charts

Description

This function creates node styles formatted for the DiagrammeR::mermaid() function.

Usage

node_style(gedcom, xref)

Arguments

gedcom

A tidyged object.

xref

The xref of the Individual or Family Group record.

Value

A string describing a node style to use in the DiagrammeR::mermaid() function.


jl5000/visged documentation built on June 15, 2022, 8:38 p.m.