| node_style | R Documentation |
This function creates node styles formatted for the DiagrammeR::mermaid() function.
node_style(gedcom, xref)
gedcom |
A tidyged object. |
xref |
The xref of the Individual or Family Group record. |
A string describing a node style to use in the DiagrammeR::mermaid() function.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.